@@ -1,6 +1,6 @@
-'use strict';
-const styles = require('ansi-styles');
-const chalk = require('..');
+import process from 'node:process';
+import styles from 'ansi-styles';
+import chalk from '../source/index.js';
 
 // Generates screenshot
 for (const key of Object.keys(styles)) {
